@@ -1,10 +1,7 @@
 #ifndef __THAI_SHAPER_H__
 #define __THAI_SHAPER_H__
 
-#ifdef HAVE_X
-#include "pangox.h"
-#endif
-
+#define isthai(wc)      (wc >= 0xE00 && wc < 0xE80)
 #define ucs2tis(wc)     (unsigned int)((unsigned int)(wc) - 0x0E00 + 0xA0)
 #define tis2uni(c)      ((gunichar)(c) - 0xA0 + 0x0E00)
 
@@ -14,7 +11,6 @@ typedef struct _ThaiFontInfo ThaiFontInfo;
  */
 typedef enum {
   THAI_FONT_NONE,
-  THAI_FONT_XTIS,
   THAI_FONT_TIS,
   THAI_FONT_TIS_MAC,
   THAI_FONT_TIS_WIN,
@@ -30,25 +26,26 @@ struct _ThaiFontInfo
 {
   PangoFont       *font;
   ThaiFontSet      font_set;
-#ifdef HAVE_X
-  PangoXSubfont    subfont; /* For X backend */
-#endif
-
-  PangoGlyph
-  (*make_glyph) (ThaiFontInfo *font_info, unsigned int c);
-
-  PangoGlyph
-  (*make_unknown_glyph) (ThaiFontInfo *font_info, unsigned int c);
-	
-  gboolean
-  (*has_glyph) (ThaiFontInfo *font_info, PangoGlyph glyph);
 };
 
+/*
+ * Abstract methods (implemented by each shaper module)
+ */
+ThaiFontInfo *
+thai_get_font_info (PangoFont *font);
+
+PangoGlyph
+thai_make_glyph (ThaiFontInfo *font_info, unsigned int c);
+
+PangoGlyph
+thai_make_unknown_glyph (ThaiFontInfo *font_info, unsigned int c);
+
 /*
  * Public functions
  */
 void
-thai_engine_shape (ThaiFontInfo     *font_info,
+thai_engine_shape (PangoEngineShape *engine,
+		   PangoFont        *font,
                    const char       *text,
                    gint              length,
                    PangoAnalysis    *analysis,
