@@ -858,6 +858,7 @@ span_parse_func     (MarkupData            *md,
   const char *strikethrough = NULL;
   const char *rise = NULL;
   const char *lang = NULL;
+  const char *fallback = NULL;
   
   g_markup_parse_context_get_position (context,
                                        &line_number, &char_number);
@@ -932,6 +933,11 @@ span_parse_func     (MarkupData            *md,
           CHECK_DUPLICATE (lang);
           lang = values[i];
         }
+      else if (strcmp (names[i], "fallback") == 0)
+        {
+          CHECK_DUPLICATE (fallback);
+          fallback = values[i];
+        }
       else
         {
           g_set_error (error, G_MARKUP_ERROR,
@@ -1145,6 +1151,8 @@ span_parse_func     (MarkupData            *md,
         ul = PANGO_UNDERLINE_DOUBLE;
       else if (strcmp (underline, "low") == 0)
         ul = PANGO_UNDERLINE_LOW;
+      else if (strcmp (underline, "error") == 0)
+        ul = PANGO_UNDERLINE_ERROR;
       else if (strcmp (underline, "none") == 0)
         ul = PANGO_UNDERLINE_NONE;
       else
@@ -1182,6 +1190,25 @@ span_parse_func     (MarkupData            *md,
         }
     }
 
+  if (fallback)
+    {
+      if (strcmp (fallback, "true") == 0)
+        add_attribute (tag, pango_attr_fallback_new (TRUE));
+      else if (strcmp (fallback, "false") == 0)
+        add_attribute (tag, pango_attr_fallback_new (FALSE));
+      else
+        {
+          g_set_error (error,
+                       G_MARKUP_ERROR,
+                       G_MARKUP_ERROR_INVALID_CONTENT,
+                       _("'fallback' attribute on <span> tag "
+                         "line %d should have one of the values "
+                         "'true' or 'false': '%s' is not valid"),
+                       line_number, fallback);
+          goto error;
+        }
+    }
+
   if (rise)
     {
       char *end = NULL;
